﻿using BreadCrumbs.Utility;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace BreadCrumbs.Views
{
    /// <summary>
    /// Interaction logic for BreadCrumbs.xaml
    /// </summary>
    public partial class BreadCrumbs : UserControl
    {
        public IParent SelectedItem
        {
            get { return (IParent)GetValue(SelectedItemProperty); }
            set { SetValue(SelectedItemProperty, value); }
        }

        // Using a DependencyProperty as the backing store for SelectedItem.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty SelectedItemProperty =
            DependencyProperty.Register("SelectedItem", typeof(IParent), typeof(BreadCrumbs), new PropertyMetadata(null, OnSelectedItemChanged));

        private static void OnSelectedItemChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            ((BreadCrumbs)d).BuildPath(e.NewValue as IParent);
        }

        
        public BreadCrumbs()
        {
            InitializeComponent();
        }

        private void BuildPath(IParent Node)
        {
            pnlContent.Children.Clear();
            while (Node != null)
            {
                Button b = new Button();
                b.Content = Node.ToString();
                b.Click += b_Click;
                b.Tag = Node;
                pnlContent.Children.Insert(0, b);
                Node = Node.Parent;
                //if we have more parents then we want a seperator
                if (Node != null)
                {
                    Label seperator = new Label();
                    seperator.Content = ">>";
                    pnlContent.Children.Insert(0, seperator);
                }
            }
        }

        void b_Click(object sender, RoutedEventArgs e)
        {
            IParent selectedItem = ((Button)sender).Tag as IParent;
            SelectedItem = selectedItem;
        }
    }
}
